#!/usr/bin/env python
# -*- coding: utf-8 -*-
# $Id: urls.py 11517 2019-05-03 12:53:40Z Andy $
#
# Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
#
# Licensed under the Proprietary License,
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at our web site.
#
# See the License for the specific language governing permissions and
# limitations under the License.
#
# $Author: Andy $
# $Date: 2019-05-03 20:53:40 +0800 (Fri, 03 May 2019) $
# $Revision: 11517 $

from django.conf.urls import include, url
# Required import for 404 handle.
from django.conf.urls import handler404
# Required import for 500 handle.
from django.conf.urls import handler500
from django.views.generic.base import TemplateView as direct_to_template

from django.contrib import admin
admin.autodiscover()

from Iuno.Patch import patterns

from . import settings

urlpatterns = patterns('')

import Iuno
Iuno.attachURLs(settings, urlpatterns)

urlpatterns += patterns('',
    (r'^i18n/', include('Iuppiter.i18n.urls')),
    (r'^admin/', include(admin.site.urls)),
)


